prespy
======

Details
-------

A currently rough collection of modules and scripts for working with the
NBS Presentation data in various ways.

Requirements
------------

The following are required by certain elements of the package and may
need to be installed separately if you are using them.

-  numpy (required by mri module and scla subpackage
-  scipy (required by scla subpackage)
-  matplotlib (required by scla subpackage)

